==> virtuoso-opensource-4.5.7.tar.gz: virtuoso-opensource-4.5.7/binsrc/vad/oper_pars.sql <==
--  
--  $Id: oper_pars.sql,v 1.2 2006/08/16 07:58:13 source Exp $
--
--  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
--  project.
--  
--  Copyright (C) 1998-2006 OpenLink Software
--  
--  This project is free software; you can redistribute it and/or modify it
--  under the terms of the GNU General Public License as published by the
--  Free Software Foundation; only version 2 of the License, dated June 1991.
--  
--  This program is distributed in the hope that it will be useful, but
--  WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--  General Public License for more details.
--  
--  You should have received a copy of the GNU General Public License along
--  with this program; if not, write to the Free Software Foundation, Inc.,
--  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
--  
--  

insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'reg_curdir','1','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tree_node_clicked','0','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tree_ser','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'reg_action','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_folder_name','new_folder','Name of new folder','Name of new folder to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_name','new_item','Name of new Item','Name of new intem to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_value','','Value of new Item','Value of new intem to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'old_item_value','','Old value of new Item','Old value of new intem to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_type','STRING','Type of new Item','Type of new intem to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'del_item_id','','Handle of been deleting item','Handle of been deleting item')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'items_list','','Content of current folder','Content of current folder')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'result_txt','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'packages_list','','The list of existing packages','The list of existing packages')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_pkg_name','./tmp/new_package.vad','Path of new Package','Path of new intem to be installed at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tmp','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'docs_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'http_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'code_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'data_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'last_error','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'password','','User Password','This string authenticates the user in terms of Virtuoso DBMS core.<br>')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'user','','User Name','This string identifies the user in terms of Virtuoso DBMS core.<br>')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'datasource','','Selected Datasource','Selected Datasource')
;

==> virtuoso-opensource-5.0.1.tar.gz: virtuoso-opensource-5.0.1/binsrc/vad/oper_pars.sql <==
--  
--  $Id: oper_pars.sql,v 1.3 2007/01/22 13:57:19 source Exp $
--
--  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
--  project.
--  
--  Copyright (C) 1998-2006 OpenLink Software
--  
--  This project is free software; you can redistribute it and/or modify it
--  under the terms of the GNU General Public License as published by the
--  Free Software Foundation; only version 2 of the License, dated June 1991.
--  
--  This program is distributed in the hope that it will be useful, but
--  WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--  General Public License for more details.
--  
--  You should have received a copy of the GNU General Public License along
--  with this program; if not, write to the Free Software Foundation, Inc.,
--  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
--  
--  

insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'reg_curdir','1','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tree_node_clicked','0','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tree_ser','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'reg_action','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_folder_name','new_folder','Name of new folder','Name of new folder to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_name','new_item','Name of new Item','Name of new item to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_value','','Value of new Item','Value of new item to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'old_item_value','','Old value of new Item','Old value of new item to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_item_type','STRING','Type of new Item','Type of new item to be created at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'del_item_id','','Handle of been deleting item','Handle of been deleting item')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'items_list','','Content of current folder','Content of current folder')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'result_txt','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'packages_list','','The list of existing packages','The list of existing packages')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'new_pkg_name','./tmp/new_package.vad','Path of new Package','Path of new item to be installed at current path')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'tmp','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'docs_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'http_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'code_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'data_root','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'last_error','','','')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'password','','User Password','This string authenticates the user in terms of Virtuoso DBMS core.<br>')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'user','','User Name','This string identifies the user in terms of Virtuoso DBMS core.<br>')
;
insert replacing "VAD"."DBA"."VAD_HELP" ("name","dflt","short_help","full_help") values (
'datasource','','Selected Datasource','Selected Datasource')
;
